@@ -450,7 +450,7 @@ Example: $0 --help run.
         default: 'firefox-desktop',
         demandOption: false,
         type: 'array',
-        choices: ['firefox-desktop', 'firefox-android'],
+        choices: ['firefox-desktop', 'firefox-android', 'chromium'],
       },
       'firefox': {
         alias: ['f', 'firefox-binary'],
@@ -471,6 +471,18 @@ Example: $0 --help run.
         demandOption: false,
         type: 'string',
       },
+      'chromium-binary': {
+        describe: 'Path or alias to a Chromium executable such as ' +
+          'google-chrome, google-chrome.exe or opera.exe etc. ' +
+          'If not specified, the default Google Chrome will be used.',
+        demandOption: false,
+        type: 'string',
+      },
+      'chromium-profile': {
+        describe: 'Path to a custom Chromium profile',
+        demandOption: false,
+        type: 'string',
+      },
       'keep-profile-changes': {
         describe: 'Run Firefox directly in custom profile. Any changes to ' +
                   'the profile will be saved.',
