@@ -1,5 +1,15 @@
 /* @flow */
 
+import {promisify} from 'util';
+
+// promisify.custom is missing from the node types know to flow,
+// and it triggers flow-check errors if used directly.
+// By using the value exported here, flow-check passes successfully
+// using a single FLOW_IGNORE suppress comment.
+
+// $FLOW_IGNORE: promisify.custom is missing in flow type signatures.
+export const promisifyCustom = promisify.custom;
+
 /*
  * A small promisify helper to make it easier to customize a
  * function promisified (using the 'util' module available in
