@@ -3,11 +3,12 @@ import path from 'path';
 import EventEmitter from 'events';
 import tty from 'tty';
 import stream from 'stream';
+import {promisify} from 'util';
 
+import deepcopy from 'deepcopy';
 import sinon from 'sinon';
 import yauzl from 'yauzl';
 import ExtendableError from 'es6-error';
-import promisify from 'es6-promisify';
 
 import {createLogger} from '../../src/util/logger';
 import * as defaultFirefoxApp from '../../src/firefox';
@@ -157,22 +158,15 @@ export function makeSureItFails(): Function {
 export function fake<T>(
   original: Object, methods: Object = {}, skipProperties: Array<string> = []
 ): T {
-  var stub = {};
+  const stub = {};
 
   // Provide stubs for all original members:
-  var props = [];
-  var obj = original;
-  while (obj) {
-    props = props.concat(Object.getOwnPropertyNames(obj));
-    obj = Object.getPrototypeOf(obj);
-  }
+  const proto = Object.getPrototypeOf(original);
+  const props = Object.getOwnPropertyNames(original)
+    .concat(Object.getOwnPropertyNames(proto))
+    .filter((key) => !skipProperties.includes(key));
 
-  var proto = Object.getPrototypeOf(original);
   for (const key of props) {
-    if (skipProperties.indexOf(key) >= 0 ||
-       (!original.hasOwnProperty(key) && !proto.hasOwnProperty(key))) {
-      continue;
-    }
     const definition = original[key] || proto[key];
     if (typeof definition === 'function') {
       stub[key] = () => {
@@ -280,7 +274,7 @@ export class ErrorWithCode extends Error {
 }
 
 /*
- * A basic manifest fixture using in unit tests.
+ * A basic manifest fixture used in unit tests.
  */
 export const basicManifest = {
   name: 'the extension',
@@ -292,6 +286,12 @@ export const basicManifest = {
   },
 };
 
+/*
+ * A basic manifest fixture without an applications property.
+ */
+export const manifestWithoutApps = deepcopy(basicManifest);
+delete manifestWithoutApps.applications;
+
 /*
  * A class that implements an empty IExtensionRunner interface.
  */
