@@ -351,6 +351,31 @@ describe('util/extension-runners/firefox-android', () => {
          );
        });
 
+    it('supports custom prefs via --pref', async () => {
+      const fakeFirefoxApp = {
+        createProfile: sinon.spy(() => {
+          return Promise.resolve({profileDir: '/path/to/fake/profile'});
+        }),
+      };
+      const {params} = prepareSelectedDeviceAndAPKParams({
+        fakeFirefoxApp,
+      });
+
+      // cmd/run.js maps --pref to customPrefs.
+      params.customPrefs = {'some.pref.name': 123};
+
+      const runnerInstance = new FirefoxAndroidExtensionRunner(params);
+      await runnerInstance.run();
+
+      sinon.assert.calledWithMatch(
+        fakeFirefoxApp.createProfile,
+        {
+          app: 'fennec',
+          customPrefs: {'some.pref.name': 123},
+        },
+      );
+    });
+
     it('builds and pushes the extension xpi to the android device',
        async () => {
          const {
@@ -845,7 +870,7 @@ describe('util/extension-runners/firefox-android', () => {
         {
           params: {profilePath: '/fake/dir'},
           expectedMessage: (
-            /Android target does not support custom profile paths/
+            /Android target does not support --profile-path/
           ),
         },
         {
@@ -863,13 +888,19 @@ describe('util/extension-runners/firefox-android', () => {
         {
           params: {preInstall: true},
           expectedMessage: (
-            /Android target does not support --pre-install option/
+            /Android target does not support --pre-install/
           ),
         },
         {
           params: {startUrl: 'http://fake-start-url.org'},
           expectedMessage: (
-            /Android target does not support --start-url option/
+            /Android target does not support --start-url/
+          ),
+        },
+        {
+          params: {args: ['-headless=false']},
+          expectedMessage: (
+            /Android target does not support --args/
           ),
         },
       ];
