@@ -37,11 +37,18 @@ ${fakeSocketFilePrefix}  ${fakeRDPUnixSocketFile}
 
 // NOTE: fake 'pm dump <APK>' output related to the granted permissions for an
 // android application.
-const fakeAndroidGrantedPermissions = `
+const fakeAndroidGrantedPermissionsColon = `
 android.permission.READ_EXTERNAL_STORAGE: granted=true
 android.permission.WRITE_EXTERNAL_STORAGE: granted=true
 `;
 
+// Some Android device uses a comma instead of a double colon
+// (See #1583).
+const fakeAndroidGrantedPermissionsComma = `
+android.permission.READ_EXTERNAL_STORAGE, granted=true
+android.permission.WRITE_EXTERNAL_STORAGE, granted=true
+`;
+
 const {assert} = chai;
 
 function getFakeADBKit(
@@ -50,7 +57,7 @@ function getFakeADBKit(
   const fakeTransfer = new EventEmitter();
   const adbUtilReadAllStub = sinon.stub();
 
-  adbUtilReadAllStub.onCall(0).returns(Promise.resolve(new Buffer('')));
+  adbUtilReadAllStub.onCall(0).returns(Promise.resolve(Buffer.from('')));
 
   const fakeADBClient = {
     listDevices: sinon.spy(() => {
@@ -188,7 +195,7 @@ describe('utils/adb', () => {
         },
         adbkitUtil: {
           readAll: sinon.spy(() => {
-            return Promise.resolve(new Buffer('fake_data_result'));
+            return Promise.resolve(Buffer.from('fake_data_result'));
           }),
         },
       });
@@ -226,7 +233,7 @@ describe('utils/adb', () => {
         },
         adbkitUtil: {
           readAll: sinon.spy(() => {
-            return Promise.resolve(new Buffer(fakeADBPackageList));
+            return Promise.resolve(Buffer.from(fakeADBPackageList));
           }),
         },
       });
@@ -285,9 +292,7 @@ describe('utils/adb', () => {
         },
         adbkitUtil: {
           readAll: sinon.spy(() => {
-            return Promise.resolve(
-              new Buffer('UnexpectedNaN')
-            );
+            return Promise.resolve(Buffer.from('UnexpectedNaN'));
           }),
         },
       });
@@ -313,9 +318,7 @@ describe('utils/adb', () => {
         },
         adbkitUtil: {
           readAll: sinon.spy(() => {
-            return Promise.resolve(
-              new Buffer('21')
-            );
+            return Promise.resolve(Buffer.from('21'));
           }),
         },
       });
@@ -362,10 +365,8 @@ describe('utils/adb', () => {
            },
            adbkitUtil: {
              readAll: sinon.spy(() => {
-               return Promise.resolve(
-                 // No granted permissions in the output.
-                 new Buffer('')
-               );
+               // No granted permissions in the output.
+               return Promise.resolve(Buffer.from(''));
              }),
            },
          });
@@ -392,36 +393,41 @@ describe('utils/adb', () => {
          );
        });
 
-    it('does not reject when all the required permissions have been granted',
-       async () => {
-         const adb = getFakeADBKit({
-           adbClient: {
-             shell: sinon.spy(() => Promise.resolve('')),
-           },
-           adbkitUtil: {
-             readAll: sinon.spy(() => {
-               return Promise.resolve(
-                 new Buffer(fakeAndroidGrantedPermissions)
-               );
-             }),
-           },
-         });
-         const adbUtils = new ADBUtils({adb});
+    describe('Android Granted Permissions discovery', async () => {
+      async function assertPermissions(fakeAndroidPmDump) {
+        const adb = getFakeADBKit({
+          adbClient: {
+            shell: sinon.spy(() => Promise.resolve('')),
+          },
+          adbkitUtil: {
+            readAll: sinon.spy(() => {
+              return Promise.resolve(Buffer.from(fakeAndroidPmDump));
+            }),
+          },
+        });
+        const adbUtils = new ADBUtils({adb});
 
-         const promise = adbUtils.ensureRequiredAPKRuntimePermissions(
-           'device1', 'org.mozilla.firefox', [
-             'android.permission.READ_EXTERNAL_STORAGE',
-             'android.permission.WRITE_EXTERNAL_STORAGE',
-           ]
-         );
+        const promise = adbUtils.ensureRequiredAPKRuntimePermissions(
+          'device1', 'org.mozilla.firefox', [
+            'android.permission.READ_EXTERNAL_STORAGE',
+            'android.permission.WRITE_EXTERNAL_STORAGE',
+          ]
+        );
 
-         await assert.isFulfilled(promise);
-         sinon.assert.calledOnce(adb.fakeADBClient.shell);
-         sinon.assert.calledWith(
-           adb.fakeADBClient.shell,
-           'device1', ['pm', 'dump', 'org.mozilla.firefox']
-         );
-       });
+        await assert.isFulfilled(promise);
+        sinon.assert.calledOnce(adb.fakeADBClient.shell);
+        sinon.assert.calledWith(
+          adb.fakeADBClient.shell,
+          'device1', ['pm', 'dump', 'org.mozilla.firefox']
+        );
+      }
+
+      it('detects permissions on pm versions that uses colon separator',
+         () => assertPermissions(fakeAndroidGrantedPermissionsColon));
+
+      it('detects permissions on pm versions that uses comma separator',
+         () => assertPermissions(fakeAndroidGrantedPermissionsComma));
+    });
   });
 
   describe('amForceStopAPK', () => {
@@ -485,7 +491,7 @@ describe('utils/adb', () => {
           shell: sinon.spy(() => Promise.resolve('')),
         },
         adbkitUtil: {
-          readAll: sinon.spy(() => Promise.resolve(new Buffer('0\n'))),
+          readAll: sinon.spy(() => Promise.resolve(Buffer.from('0\n'))),
         },
       });
       const adbUtils = new ADBUtils({adb});
@@ -510,7 +516,7 @@ describe('utils/adb', () => {
           shell: sinon.spy(() => Promise.resolve('')),
         },
         adbkitUtil: {
-          readAll: sinon.spy(() => Promise.resolve(new Buffer('1\n'))),
+          readAll: sinon.spy(() => Promise.resolve(Buffer.from('1\n'))),
         },
       });
       const adbUtils = new ADBUtils({adb});
@@ -537,7 +543,7 @@ describe('utils/adb', () => {
              shell: sinon.spy(() => Promise.resolve('')),
            },
            adbkitUtil: {
-             readAll: sinon.spy(() => Promise.resolve(new Buffer('1\n'))),
+             readAll: sinon.spy(() => Promise.resolve(Buffer.from('1\n'))),
            },
          });
          const adbUtils = new ADBUtils({adb});
@@ -582,7 +588,7 @@ describe('utils/adb', () => {
           shell: sinon.spy(() => Promise.resolve('')),
         },
         adbkitUtil: {
-          readAll: sinon.spy(() => Promise.resolve(new Buffer('\n'))),
+          readAll: sinon.spy(() => Promise.resolve(Buffer.from('\n'))),
         },
       });
       const adbUtils = new ADBUtils({adb});
@@ -695,7 +701,7 @@ describe('utils/adb', () => {
           startActivity: sinon.spy(() => Promise.resolve()),
         },
         adbkitUtil: {
-          readAll: sinon.spy(() => Promise.resolve(new Buffer('\n'))),
+          readAll: sinon.spy(() => Promise.resolve(Buffer.from('\n'))),
         },
       });
       const adbUtils = new ADBUtils({adb});
@@ -749,9 +755,7 @@ describe('utils/adb', () => {
         },
         adbkitUtil: {
           readAll: sinon.spy(() => {
-            return Promise.resolve(
-              new Buffer('')
-            );
+            return Promise.resolve(Buffer.from(''));
           }),
         },
       });
@@ -784,9 +788,7 @@ describe('utils/adb', () => {
         },
         adbkitUtil: {
           readAll: sinon.spy(() => {
-            return Promise.resolve(
-              new Buffer('')
-            );
+            return Promise.resolve(Buffer.from(''));
           }),
         },
       });
@@ -825,7 +827,7 @@ describe('utils/adb', () => {
              readAll: sinon.spy(() => {
                // Fake unexpected multiple RDP socket matches.
                return Promise.resolve(
-                 new Buffer(`${fakeUnixSocketFiles}${fakeUnixSocketFiles}`)
+                 Buffer.from(`${fakeUnixSocketFiles}${fakeUnixSocketFiles}`)
                );
              }),
            },
@@ -855,9 +857,7 @@ describe('utils/adb', () => {
         adbkitUtil: {
           readAll: sinon.spy(() => {
             // Fake unexpected multiple RDP socket matches.
-            return Promise.resolve(
-              new Buffer(fakeUnixSocketFiles)
-            );
+            return Promise.resolve(Buffer.from(fakeUnixSocketFiles));
           }),
         },
       });
